@@ -85,7 +85,9 @@ def init_project(package_entry_filepath):
         with activate_project_nocheck(project_dir):
             jl_module_name = get_project_name_checked(project_dir)
             exec_julia(
-                "TyPython.CPython.@suppress_error begin import {0};TyPython.CPython.init();{0}.init() end".format(jl_module_name)
+                "TyPython.CPython.@suppress_error begin import {0};TyPython.CPython.init();{0}.init() end".format(
+                    jl_module_name
+                )
             )
     except JuliaError:
         with activate_project_checked(project_dir):
